<?php
/**
 * Fonctions d'installation, mise à jours et désinstallation du plugin SPIP
 *
 * @author		Jonathan OCHEJ
 * @license		MIT - https://github.com/GouvernementFR/dsfr/blob/main/LICENSE.md
 * 
 **/
if ( !defined('_ECRIRE_INC_VERSION') ) {
	return;
}

/**
 * Fonction d'installation et de mise à jour du plugin SPIP
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *     Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 **/
function dsfr_composants_upgrade($nom_meta_base_version, $version_cible) {
	include_spip('inc/dsfr_composants');

	$maj = [];

	// uniquement lors de la première installation
	$maj['create'] = [
		['effacer_meta', 'dsfr_composants'], // efface les metas en cas de mauvaise désinstallation du plugin
		['dsfr_composants_purger'], // purge le cache
	];

	// le schéma de chaque version est un nombre entier,
	// cela permet de créer automatiquement les mise à jours à faire si la fonction php correspondante existe
	for ( $version = 1; $version <= (int) $version_cible; $version++ ) {
		if ( function_exists('dsfr_composants_upgrade_v'.$version) ) {
			$maj[(string) $version] = [
				['dsfr_composants_upgrade_v'.$version]
			];
		}
	}

	// permet de purger automatiquement le cache après chaque mise à jour
	if ( !array_key_exists($version_cible, $maj) ) $maj[$version_cible] = [];
	$maj[$version_cible][] = ['dsfr_composants_purger'];

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * Fonction de désinstallation du plugin SPIP
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 **/
function dsfr_composants_vider_tables($nom_meta_base_version) {
	effacer_meta('dsfr_composants');
	effacer_meta($nom_meta_base_version);
}